@@ -1,5 +1,5 @@
 package HackaMol::Roles::AtomGroupRole;
-$HackaMol::Roles::AtomGroupRole::VERSION = '0.021';
+$HackaMol::Roles::AtomGroupRole::VERSION = '0.022';
 #ABSTRACT: Role for a group of atoms
 use Moose::Role;
 use Carp;
@@ -16,13 +16,20 @@ has 'atoms' => (
     isa     => 'ArrayRef[HackaMol::Atom]',
     default => sub { [] },
     handles => {
-        push_atoms   => 'push',
-        get_atoms    => 'get',
-        set_atoms    => 'set',
-        delete_atoms => 'delete',
-        all_atoms    => 'elements',
-        count_atoms  => 'count',
-        clear_atoms  => 'clear',
+        push_atoms    => 'push',
+        select_atoms  => 'grep',
+        map_atoms     => 'map',
+        first_atoms   => 'first',
+        sort_atoms    => 'sort',
+        splice_atoms  => 'splice',
+        insert_atoms  => 'insert',
+        shuffle_atoms => 'shuffle',
+        get_atoms     => 'get',
+        set_atoms     => 'set',
+        delete_atoms  => 'delete',
+        all_atoms     => 'elements',
+        count_atoms   => 'count',
+        clear_atoms   => 'clear',
     },
     lazy => 1,
 );
@@ -363,7 +370,7 @@ HackaMol::Roles::AtomGroupRole - Role for a group of atoms
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
