@@ -1,5 +1,5 @@
 package HackaMol::Roles::ReadZmatRole;
-$HackaMol::Roles::ReadZmatRole::VERSION = '0.021';
+$HackaMol::Roles::ReadZmatRole::VERSION = '0.022';
 # ABSTRACT: Read files with molecular information
 use Moo::Role;
 use strictures 2;
@@ -21,8 +21,6 @@ sub read_zmat_atoms {
 
     my @atoms;
     my ( $n, $t ) = ( 0, 0 );
-
-    my $nat  = undef;
   
     my @zmat = <$fh>;
     @zmat = _substitute_variables(@zmat);
@@ -126,6 +124,7 @@ sub read_zmat_atoms {
             coords => [$d]
         );
     }
+    $atoms[$_]->iatom($_) foreach ( 0 .. $#atoms );
     return (@atoms);
 
 }
@@ -170,7 +169,7 @@ HackaMol::Roles::ReadZmatRole - Read files with molecular information
 
 =head1 VERSION
 
-version 0.021
+version 0.022
 
 =head1 SYNOPSIS
 
@@ -183,18 +182,27 @@ The HackaMol::Roles::ReadZmatRole provides read_zmat_atoms for the flexible read
 It supports inline cartesian coordinates and variables as in the following example:
 
 N 0     -12.781   3.620  15.274 
+
 C 0     -11.976   4.652  15.944 
+
 C 0     -12.722   6.019  15.985 
+
 O 0     -13.133   6.378  14.897 
+
 C 2  CBCA 3 CBCAC 4 CBCACO 
+
 C 5  CBCA 2 CBCAC 3 CG1CBCAC
+
 C 5  CBCA 2 CBCAC 3 CG2CBCAC
+
 CBCA    = 1.54
-CBCA    = 1.54
-CBCA    = 1.54
+
 CBCAC   = 113.4
+
 CBCACO  = 71.85
+
 CG1CBCAC = 54. 
+
 CG2CBCAC = 180.
 
 =head1 METHODS
